@@ -11,7 +11,8 @@ use bindgen::callbacks::{DeriveTrait, EnumVariantValue, ImplementsTrait, MacroPa
 use bindgen::NonCopyUnionStyle;
 use eyre::{eyre, WrapErr};
 use pgrx_pg_config::{
-    is_supported_major_version, PgConfig, PgConfigSelector, Pgrx, SUPPORTED_VERSIONS,
+    is_supported_major_version, PgConfig, PgConfigSelector, PgMinorVersion, PgVersion, Pgrx,
+    SUPPORTED_VERSIONS,
 };
 use quote::{quote, ToTokens};
 use std::cell::RefCell;
@@ -26,6 +27,20 @@ use syn::{ForeignItem, Item, ItemConst};
 
 const BLOCKLISTED_TYPES: [&str; 3] = ["Datum", "NullableDatum", "Oid"];
 
+// These postgres versions were effectively "yanked" by the community, even tho they still exist
+// in the wild.  pgrx will refuse to compile against them
+const YANKED_POSTGRES_VERSIONS: &[PgVersion] = &[
+    // this set of releases introduced an ABI break in the [`pg_sys::ResultRelInfo`] struct
+    // and was replaced by the community on 2024-11-21
+    // https://www.postgresql.org/about/news/postgresql-172-166-1510-1415-1318-and-1222-released-2965/
+    PgVersion::new(17, PgMinorVersion::Release(1), None),
+    PgVersion::new(16, PgMinorVersion::Release(5), None),
+    PgVersion::new(15, PgMinorVersion::Release(9), None),
+    PgVersion::new(14, PgMinorVersion::Release(14), None),
+    PgVersion::new(13, PgMinorVersion::Release(17), None),
+    PgVersion::new(12, PgMinorVersion::Release(21), None),
+];
+
 pub(super) mod clang;
 pub(super) mod sym_blocklist;
 
@@ -209,6 +224,7 @@ pub fn main() -> eyre::Result<()> {
                 ))
             }
         };
+
         let found_major = found_ver.major;
         if let Ok(pg_config) = PgConfig::from_env() {
             let major_version = pg_config.major_version()?;
@@ -222,6 +238,17 @@ pub fn main() -> eyre::Result<()> {
             vec![(found_ver.major, specific)]
         }
     };
+
+    // make sure we're not trying to build any of the yanked postgres versions
+    for (_, pg_config) in &pg_configs {
+        let version = pg_config.get_version()?;
+        if YANKED_POSTGRES_VERSIONS.contains(&version) {
+            panic!("Postgres v{}{} is incompatible with \
+                    other versions in this major series and is not supported by pgrx.  Please upgrade \
+                    to the latest version in the v{} series.", version.major, version.minor, version.major);
+        }
+    }
+
     std::thread::scope(|scope| {
         // This is pretty much either always 1 (normally) or 5 (for releases),
         // but in the future if we ever have way more, we should consider
